@@ -48,6 +48,7 @@ WaylandConfig::WaylandConfig(QObject *parent)
     , m_blockSignals(true)
     , m_newOutputId(0)
     , m_kscreenConfig(nullptr)
+    , m_kscreenPendingConfig(nullptr)
     , m_screen(new WaylandScreen(this))
 {
     connect(this, &WaylandConfig::initialized, &m_syncLoop, &QEventLoop::quit);
@@ -274,6 +275,15 @@ QMap<int, WaylandOutput*> WaylandConfig::outputMap() const
     return m_outputMap;
 }
 
+void WaylandConfig::tryPendingConfig()
+{
+    if (!m_kscreenPendingConfig) {
+        return;
+    }
+    applyConfig(m_kscreenPendingConfig);
+    m_kscreenPendingConfig = nullptr;
+}
+
 void WaylandConfig::applyConfig(const KScreen::ConfigPtr &newConfig)
 {
     using namespace KWayland::Client;
@@ -281,6 +291,12 @@ void WaylandConfig::applyConfig(const KScreen::ConfigPtr &newConfig)
     auto wlOutputConfiguration = m_outputManagement->createConfiguration();
     bool changed = false;
 
+    if (m_blockSignals) {
+        /* Last apply still pending, remember new changes and apply afterwards */
+        m_kscreenPendingConfig = newConfig;
+        return;
+    }
+
     Q_FOREACH (auto output, newConfig->outputs()) {
         auto o_old = m_outputMap[output->id()];
         auto device = o_old->outputDevice();
@@ -300,9 +316,9 @@ void WaylandConfig::applyConfig(const KScreen::ConfigPtr &newConfig)
             wlOutputConfiguration->setPosition(o_old->outputDevice(), output->pos());
         }
 
-        if (device->scale() != output->scale()) {
+        if (!qFuzzyCompare(device->scaleF(), output->scale())) {
             changed = true;
-            wlOutputConfiguration->setScale(o_old->outputDevice(), output->scale());
+            wlOutputConfiguration->setScaleF(o_old->outputDevice(), output->scale());
         }
 
         // rotation
@@ -334,11 +350,13 @@ void WaylandConfig::applyConfig(const KScreen::ConfigPtr &newConfig)
         wlOutputConfiguration->deleteLater();
         unblockSignals();
         Q_EMIT configChanged(toKScreenConfig());
+        tryPendingConfig();
     });
     connect(wlOutputConfiguration, &OutputConfiguration::failed, this, [this, wlOutputConfiguration] {
         wlOutputConfiguration->deleteLater();
         unblockSignals();
         Q_EMIT configChanged(toKScreenConfig());
+        tryPendingConfig();
     });
     blockSignals();
     // Now ask the compositor to apply the changes
