@@ -21,10 +21,12 @@
 #include "output.h"
 #include "backendmanager_p.h"
 #include "abstractbackend.h"
-#include "debug_p.h"
+#include "kscreen_debug.h"
 
 #include <QDebug>
 #include <QRect>
+#include <QStringList>
+#include <QCryptographicHash>
 
 using namespace KScreen;
 
@@ -219,6 +221,19 @@ ConfigPtr Config::clone() const
     return newConfig;
 }
 
+QString Config::connectedOutputsHash() const
+{
+    QStringList hashedOutputs;
+
+    const auto outputs = connectedOutputs();
+    for (const OutputPtr &output : outputs) {
+        hashedOutputs << output->hash();
+    }
+    std::sort(hashedOutputs.begin(), hashedOutputs.end());
+    const auto hash = QCryptographicHash::hash(hashedOutputs.join(QString()).toLatin1(),
+                                               QCryptographicHash::Md5);
+    return QString::fromLatin1(hash.toHex());
+}
 
 ScreenPtr Config::screen() const
 {
@@ -315,7 +330,7 @@ void Config::removeOutput(int outputId)
     d->removeOutput(d->outputs.find(outputId));
 }
 
-void Config::setOutputs(OutputList outputs)
+void Config::setOutputs(const OutputList &outputs)
 {
     for (auto iter = d->outputs.begin(), end = d->outputs.end(); iter != end; ) {
         iter = d->removeOutput(iter);
